@@ -2,5 +2,5 @@
 
 from lace.cli import main
 
-if __name__ == '__main__':
-    main()
\ No newline at end of file
+if __name__ == "__main__":
+    main()
