@@ -125,7 +125,7 @@ class LaceClient:
             or os.getenv("LACE_API_BASE")
             or os.getenv("LACE_API_URL")  # Legacy support
             or config.get("api_base")
-            or "https://usgf90tw68.execute-api.eu-west-1.amazonaws.com/prod"
+            or "https://uqxtvsw8oi.execute-api.eu-west-1.amazonaws.com"
         )
 
         # Set up HTTP client with proxy support
@@ -147,7 +147,8 @@ class LaceClient:
         }
 
         if self.api_key:
-            # Use uppercase X-API-Key for API Gateway compatibility
+            # Prefer standard Authorization header; keep X-API-Key for compatibility
+            self.headers["Authorization"] = f"Bearer {self.api_key}"
             self.headers["X-API-Key"] = self.api_key
 
     def _load_config(self) -> dict:
@@ -428,6 +429,32 @@ class LaceClient:
         )
         return response
 
+    # ------------------------------------------------------------
+    # TDM Opt-out Check (cloud)
+    # ------------------------------------------------------------
+    def check_tdm(self, payload: dict) -> dict:
+        """
+        Perform a cloud-backed TDM opt-out check.
+
+        Args:
+            payload: {
+              "dataset_summary": {"files": int, "bytes": int},
+              "domains": [{"d": str, "c": int}],
+              "options": {"as_of": str|None, "privacy": str|None, "ua": list[str]|None}
+            }
+        Returns:
+            dict with summary and optional evidence info
+        """
+        status, response = self._request(
+            "POST",
+            "/api/v1/check/tdm",
+            json_data={
+                "mode": "tdm_v1",
+                **payload,
+            },
+        )
+        return response
+
     def health(self) -> dict:
         """Check API health."""
         status, response = self._request("GET", "/api/health", retry=False)
@@ -689,6 +716,9 @@ class LaceClient:
             # Ensure relpath exists
             if "relpath" not in f:
                 f["relpath"] = f.get("relpath") or Path(f.get("path", "")).name
+            # Remove absolute/local path from server-bound payload (privacy)
+            if "path" in f:
+                f.pop("path", None)
             # Convert mtime to ISO8601 if it's a timestamp
             if "mtime" in f and isinstance(f["mtime"], (int, float)):
                 f["mtime"] = datetime.utcfromtimestamp(f["mtime"]).strftime(
