@@ -45,12 +45,14 @@ class LaceCloudAPI:
             or DEFAULT_API_BASE
         )
         logger.info(f"Using API base: {self.api_base}")
+        from .. import __version__
+
         self.client = httpx.Client(
             timeout=DEFAULT_TIMEOUT,
             headers={
                 "Authorization": f"Bearer {self.api_key}",
                 "x-api-key": self.api_key,  # Add for API Gateway compatibility
-                "User-Agent": "lace-client/0.7.0",
+                "User-Agent": f"lace-client/{__version__}",
             },
         )
 
