@@ -2,12 +2,7 @@
 SDS (Sufficiently Detailed Summary) generation for EU AI Act compliance.
 """
 
-from .scanner import SDSScanner
 from .questions import SDS_QUESTIONS, get_required_questions, validate_answer
+from .scanner import SDSScanner
 
-__all__ = [
-    'SDSScanner',
-    'SDS_QUESTIONS',
-    'get_required_questions',
-    'validate_answer'
-]
\ No newline at end of file
+__all__ = ["SDSScanner", "SDS_QUESTIONS", "get_required_questions", "validate_answer"]
