@@ -4,14 +4,9 @@ Lace Documentation Wizard - Privacy-first EU compliance document generation.
 
 from .analyzer import DatasetAnalyzer
 from .questions import DocumentWizard
-from .templates import TemplateGenerator
 from .storage import ImmutableStorage
+from .templates import TemplateGenerator
 
-__all__ = [
-    'DatasetAnalyzer',
-    'DocumentWizard', 
-    'TemplateGenerator',
-    'ImmutableStorage'
-]
+__all__ = ["DatasetAnalyzer", "DocumentWizard", "TemplateGenerator", "ImmutableStorage"]
 
-__version__ = '1.0.0'
\ No newline at end of file
+__version__ = "1.0.0"
